@@ -173,6 +173,9 @@ class TestBuild:
         assert build.headers["Content-Type"] == "application/json"
         assert build.headers["Authorization"] == build.token
 
+    def test_user_agent(self, build):
+        assert build.headers["User-Agent"].startswith("tuxbuild/")
+
     def test_git_sha(self, build_attrs):
         del build_attrs["git_ref"]
         build_attrs["git_sha"] = "deadbeef"
@@ -202,6 +205,9 @@ class TestBuild:
                     "target_arch": build_attrs["target_arch"],
                     "kconfig": [build_attrs["kconfig"]],
                     "client_token": mocker.ANY,
+                    "environment": {},
+                    "targets": [],
+                    "make_variables": {},
                 }
             ],
         )
@@ -224,6 +230,9 @@ class TestBuild:
                     "target_arch": build_attrs["target_arch"],
                     "kconfig": [build_attrs["kconfig"]],
                     "client_token": mocker.ANY,
+                    "environment": {},
+                    "targets": [],
+                    "make_variables": {},
                 }
             ],
         )
@@ -256,6 +265,62 @@ class TestBuild:
                     "kconfig": [build_attrs["kconfig"]],
                     "client_token": mocker.ANY,
                     "environment": build_attrs["environment"],
+                    "targets": [],
+                    "make_variables": {},
+                }
+            ],
+        )
+
+    def test_submit_build_targets(self, build, build_attrs, mocker):
+        build_attrs["targets"] = ["dtbs", "config"]
+        post_request = mocker.patch("tuxbuild.build.post_request")
+        api_build_url = build_attrs["kbapi_url"] + "/build"
+
+        build.git_ref = None
+        build.git_sha = "badbee"
+        build.targets = ["dtbs", "config"]
+        build.build()
+        post_request.assert_called_with(
+            api_build_url,
+            mocker.ANY,
+            [
+                {
+                    "git_repo": build_attrs["git_repo"],
+                    "git_sha": "badbee",
+                    "toolchain": build_attrs["toolchain"],
+                    "target_arch": build_attrs["target_arch"],
+                    "kconfig": [build_attrs["kconfig"]],
+                    "client_token": mocker.ANY,
+                    "targets": build_attrs["targets"],
+                    "environment": {},
+                    "make_variables": {},
+                }
+            ],
+        )
+
+    def test_submit_build_make_variables(self, build, build_attrs, mocker):
+        build_attrs["make_variables"] = {"W": "12", "LLVM": "1"}
+        post_request = mocker.patch("tuxbuild.build.post_request")
+        api_build_url = build_attrs["kbapi_url"] + "/build"
+
+        build.git_ref = None
+        build.git_sha = "badbee"
+        build.make_variables = {"W": "12", "LLVM": "1"}
+        build.build()
+        post_request.assert_called_with(
+            api_build_url,
+            mocker.ANY,
+            [
+                {
+                    "git_repo": build_attrs["git_repo"],
+                    "git_sha": "badbee",
+                    "toolchain": build_attrs["toolchain"],
+                    "target_arch": build_attrs["target_arch"],
+                    "kconfig": [build_attrs["kconfig"]],
+                    "client_token": mocker.ANY,
+                    "targets": [],
+                    "environment": {},
+                    "make_variables": {"W": "12", "LLVM": "1"},
                 }
             ],
         )
