@@ -133,6 +133,8 @@ def test_build_git_head(mocker, tuxbuild_config):
         kconfig_allconfig=None,
         toolchain="gcc-9",
         environment=(),
+        targets=[],
+        make_variables={},
     )
     wait_for_object.assert_called()
     assert result.exit_code == 0
@@ -500,3 +502,84 @@ def test_invalid_environment_key_value(mocker, tuxbuild_config):
     assert result.exit_code == 1
     assert build.build.call_count == 0
     assert "Key Value pair not valid:  INVALID" in result.output
+
+
+def test_build_make_targets_vars_argument():
+    """ Test calling build with --help to see targets argument"""
+    runner = CliRunner()
+    result = runner.invoke(tuxbuild.cli.build, ["--help"])
+    assert result.exit_code == 0
+    assert "[VAR=VALUE...] [target ...]" in result.output
+    assert "[KEY=VALUE | target] ..." in result.output
+
+
+def test_build_set_make_targets_vars_argument():
+    """ Test calling build with --help to see targets argument"""
+    runner = CliRunner()
+    result = runner.invoke(tuxbuild.cli.build_set, ["--help"])
+    assert result.exit_code == 0
+    assert "[VAR=VALUE...] [target ...]" in result.output
+    assert "[KEY=VALUE | target] ..." in result.output
+
+
+def test_build_valid_make_targets(mocker, tuxbuild_config):
+    Build = mocker.patch("tuxbuild.Build")
+    build = Build.return_value
+    wait_for_object = mocker.patch("tuxbuild.cli.wait_for_object")
+    runner = CliRunner()
+    result = runner.invoke(
+        tuxbuild.cli.build,
+        [
+            "--git-repo=https://git.example.com/linux.git",
+            "--git-ref=master",
+            "--target-arch=arm64",
+            "--kconfig=defconfig",
+            "--toolchain=gcc-9",
+            "dtbs config",
+        ],
+    )
+    assert result.exit_code == 0
+    assert build.build.call_count == 1
+    assert wait_for_object.call_count == 1
+
+
+def test_build_valid_make_vars(mocker, tuxbuild_config):
+    Build = mocker.patch("tuxbuild.Build")
+    build = Build.return_value
+    wait_for_object = mocker.patch("tuxbuild.cli.wait_for_object")
+    runner = CliRunner()
+    result = runner.invoke(
+        tuxbuild.cli.build,
+        [
+            "--git-repo=https://git.example.com/linux.git",
+            "--git-ref=master",
+            "--target-arch=arm64",
+            "--kconfig=defconfig",
+            "--toolchain=gcc-9",
+            "LLVM=1",
+        ],
+    )
+    assert result.exit_code == 0
+    assert build.build.call_count == 1
+    assert wait_for_object.call_count == 1
+
+
+def test_build_invalid_make_vars(mocker, tuxbuild_config):
+    Build = mocker.patch("tuxbuild.Build")
+    build = Build.return_value
+    wait_for_object = mocker.patch("tuxbuild.cli.wait_for_object")
+    runner = CliRunner()
+    result = runner.invoke(
+        tuxbuild.cli.build,
+        [
+            "--git-repo=https://git.example.com/linux.git",
+            "--git-ref=master",
+            "--target-arch=arm64",
+            "--kconfig=defconfig",
+            "--toolchain=gcc-9",
+            "LLVM=1=1",
+        ],
+    )
+    assert result.exit_code == 1
+    assert build.build.call_count == 0
+    assert wait_for_object.call_count == 0
